import { Sequelize } from 'sequelize-typescript';
import { Order, WhereOptions, Transaction, TransactionOptions } from 'sequelize';
import express from 'express';
import Tunnel from 'tunnel-ssh';
import { CkType } from '@ckstack/ck-lib';
declare class CkSequelize {
    private static DB_INFO;
    private static TUNNEL_DB_INFO;
    /**
     * tunnel 로 rdbms 에 접근 한다.
     * @param config 터널링 환경
     */
    static __connectByTunnel(config: Tunnel.Config): Promise<void>;
    /**
     * DB 에 연결 한다.
     * proxy 를 사용하지 않는 db 가 우선 연결 되며 그 다음 순서로 proxy 를 사용하는 db 가 연결 된다.
     * @param dbInfo 연결될 DB 환경
     * @param tunnelDbInfo ssh tunneling 으로 연결한다면 ssh tunneling 으로 연결될 DB 환경
     * @throws CkError
     */
    static connect(dbInfo?: Array<CkType.IDatabaseConfig>, tunnelDbInfo?: Array<CkType.ITunnelDatabaseConfig>): Promise<void>;
    /**
     * DB close 한다.
     */
    static close(): Promise<void>;
    /**
     * DB 연결 테스트를 한다. connect 이후에 반듯이 진행햐여 연결 결과를 확인 하도록 하자.
     */
    static connectTest(): Promise<boolean>;
    /**
     * Sequelzie order condition
     * @param order
     * @param sort
     * @deprecated grpc 연동하여 DB 연결을 하지 않기 때문에, 더 이상 사용 하지 않는다.
     */
    static getOrder(order: Order, sort: Array<CkType.ISqlSort>): Order;
    /**
     * Sequelize text where condition - parsing
     * @param reqIpAndLhdAndHttpInfo
     * @param where
     * @param dbOrigColumnName
     * @param sequelizeColumnName
     * @param columnValue
     * @param isAndCond 검색시 and 로 엮을지, or 로 엮을지 구분. true 라면 and 로 엮음
     * @deprecated grpc 연동하여 DB 연결을 하지 않기 때문에, 더 이상 사용 하지 않는다.
     */
    static parseSearchText(reqIpAndLhdAndHttpInfo: string, where: WhereOptions | undefined, dbOrigColumnName: string, // database column name
    sequelizeColumnName: string, // sequelize column name
    columnValue: CkType.ISqlSearch, isAndCond?: boolean): WhereOptions;
    /**
     * Sequelize text where condition - parsing
     * DB 테이블의 칼럼명과 seqelize 의 칼럼명을 동일하게 사용했을때 해당 함수를 사용 한다.
     * @param reqIpAndLhdAndHttpInfo
     * @param where
     * @param colName
     * @param columnValue
     * @param isAndCond 검색시 and 로 엮을지, or 로 엮을지 구분. true 라면 and 로 엮음
     * @deprecated grpc 연동하여 DB 연결을 하지 않기 때문에, 더 이상 사용 하지 않는다.
     */
    static parseSearchText2(reqIpAndLhdAndHttpInfo: string, where: WhereOptions | undefined, colName: string, // database column name
    columnValue: CkType.ISqlSearch, isAndCond?: boolean): WhereOptions;
    /**
     * Sequelize number where condition
     * @param reqIpAndLhdAndHttpInfo
     * @param where
     * @param sequelizeColumnName
     * @param columnValue
     * @param isAndCond 검색시 and 로 엮을지, or 로 엮을지 구분. true 라면 and 로 엮음
     * @deprecated grpc 연동하여 DB 연결을 하지 않기 때문에, 더 이상 사용 하지 않는다.
     */
    static parseSearchNumber(reqIpAndLhdAndHttpInfo: string, where: WhereOptions | undefined, sequelizeColumnName: string, columnValue: CkType.ISqlSearch, isAndCond?: boolean): WhereOptions;
    /**
     * 테이블에서 지정한 칼럼만 select 하기 위한 요청을 분석해서 sequelize attribute 에 들어갈 칼럼명 목록을 만든다.
     * 사용 예제는 ck-ms-core 의 AppService 에서 App 가져오는 부분을 확인 하자.
     * @param fields
     * @param definedCol
     * @deprecated grpc 연동하여 DB 연결을 하지 않기 때문에, 더 이상 사용 하지 않는다.
     */
    static getSelectedAttributes<T, K>(fields: Array<T>, definedCol: K): Array<string> | undefined;
    /** @deprecated */
    static getSequelize(dbNumber: number, op?: string, lk?: string, tid?: string, from?: string): Sequelize | undefined;
    /**
     * sequelize object 를 구한다. transaction 등에 사용 될 것임.
     * @param reqIpAndLhdAndHttpInfo 로그키
     * @param dbNumber 연결된 DB 의 index
     */
    static getSequelize2(reqIpAndLhdAndHttpInfo: string, dbNumber: number): Sequelize | undefined;
    /**
     * DB 를 가져오고, transaction 을 가져 온다. undefined 가 리턴 되면 transaction 가져 오기 실패.
     * @param res express 의 response object
     * @param dbNumber 연결된 DB 의 index
     * @param opt transaction option
     */
    static getTransactionForWeb(res: express.Response, dbNumber: number, opt?: TransactionOptions): Promise<Transaction | undefined>;
    /**
     * DB 를 가져오고, transaction 을 가져 온다. undefined 가 리턴 되면 transaction 가져 오기 실패.
     * raw query 로 사용 할 때는 db object 가 필요하므로, db object 도 같이 포함해서 리턴 한다.
     * raw query 를 사용 하지 않는 경우는 getTransactionForWeb 함수를 사용 한다.
     * @param res express 의 response object
     * @param dbNumber 연결된 DB 의 index
     * @param opt transaction option
     */
    static getTransactionForWebWithDB(res: express.Response, dbNumber: number, opt?: TransactionOptions): Promise<{
        transaction: Transaction | undefined;
        rdb: Sequelize | undefined;
    }>;
    /**
     * transaction 을 rollback 한다.
     * @param res express 의 response object
     */
    static rollback(res: express.Response): Promise<void>;
    /**
     * transaction 을 commit 한다.
     * @param res express 의 response object
     */
    static commit(res: express.Response): Promise<void>;
    /**
     * mysql 에서 full text 검색을 위한 where 에서 사용될 match 조건 스트링을 만든다.
     * getFullTextConditionByRep 는 sequelize raw query 의 replace 기능을 이용 하고,
     * 본 함수는 값을 직접 주어서 검색 조건을 만든다. 본 함수를 사용 하면 sql injection 이슈가 있음을 인지 해야 한다.
     * @param colName full text search 하려는 DB 칼럼명
     * @param searchValue full text search 하는 검색값
     */
    static getFullTextCondition(colName: string, searchValue: string): string;
    /**
     * mysql 에서 full text 검색을 위한 where 에서 사용될 match 조건 스트링을 만든다.
     * sql injection 이슈를 피하기 위해서, sequelize raw query 의 replace 기능을 이용 한다.
     * @param colName full text search 하려는 DB 칼럼명
     * @param searchKey sequelize raw query 에서 replace 되는 키. 가령 ':search_value' 와 같은 값을 주고, sequelize raw query replace 에서 search_value 를 변경 하도록 한다.
     */
    static getFullTextConditionByRep(colName: string, searchKey: string): string;
}
export default CkSequelize;
